API docs for “spamfighter.core.test.test_firewall”

# Module s.c.t.test_firewall

Part of spamfighter.core.test View Source

Тесты на `spamfighter.core.firewall`.

Class | FirewallStatementTestCase | Тест на `spamfighter.core.firewall.FirewallStatement`.
Class | SkipFirewallStatementTestCase | Тест на `spamfighter.core.firewall.SkipFirewallStatement`.
Class | StopFirewallStatementTestCase | Тест на `spamfighter.core.firewall.StopFirewallStatement`.
Class | DoFirewallStatementTestCase | Тест на `spamfighter.core.firewall.DoFirewallStatement`.
Class | MessageFirewallTestCase | Тест на `spamfighter.core.firewall.MessageFirewall`.